This is the mail archive of the binutils@sources.redhat.com mailing list for the binutils project.


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Re: wild_doit


On Mon, Aug 13, 2001 at 11:11:58PM +0930, Alan Modra wrote:
> wild_doit became a global in 1994.  Perhaps it's time to make the name
> a little more informative.  Any objections/improvements to this change?
> 
> 	* ldlang.c (wild_doit): Rename to lang_add_section.
> 	* ldlang.h: Here too.
> 	* mpw-elfmips.c: And here.
> 	* emultempl/beos.em: And here.
> 	* emultempl/elf32.em: And here.
> 	* emultempl/hppaelf.em: And here.
> 	* emultempl/pe.em: And here.

I checked in the following

Index: ldlang.h
===================================================================
RCS file: /cvs/src/src/ld/ldlang.h,v
retrieving revision 1.11
diff -u -p -r1.11 ldlang.h
--- ldlang.h	2001/08/03 01:11:21	1.11
+++ ldlang.h	2001/08/14 01:53:36
@@ -444,7 +444,7 @@ extern bfd_vma lang_size_sections
 	   bfd_vma dot, boolean relax));
 extern void lang_enter_group PARAMS ((void));
 extern void lang_leave_group PARAMS ((void));
-extern void wild_doit
+extern void lang_add_section
   PARAMS ((lang_statement_list_type *ptr, asection *section,
 	   lang_output_section_statement_type *output,
 	   lang_input_statement_type *file));
Index: mpw-elfmips.c
===================================================================
RCS file: /cvs/src/src/ld/mpw-elfmips.c,v
retrieving revision 1.5
diff -u -p -r1.5 mpw-elfmips.c
--- mpw-elfmips.c	2001/06/18 22:20:57	1.5
+++ mpw-elfmips.c	2001/08/14 01:53:36
@@ -605,7 +605,7 @@ gldelf32ebmip_place_orphan (file, s)
   if (hold_use != NULL)
     {
       /* We have already placed a section with this name.  */
-      wild_doit (&hold_use->children, s, hold_use, file);
+      lang_add_section (&hold_use->children, s, hold_use, file);
       return true;
     }
 
@@ -618,7 +618,7 @@ gldelf32ebmip_place_orphan (file, s)
       && strncmp (secname, ".gnu.warning.", sizeof ".gnu.warning." - 1) == 0
       && hold_text != NULL)
     {
-      wild_doit (&hold_text->children, s, hold_text, file);
+      lang_add_section (&hold_text->children, s, hold_text, file);
       return true;
     }
 
@@ -693,7 +693,7 @@ gldelf32ebmip_place_orphan (file, s)
 				       (etree_type *) NULL);
 
   os = lang_output_section_statement_lookup (secname);
-  wild_doit (&os->children, s, os, file);
+  lang_add_section (&os->children, s, os, file);
 
   lang_leave_output_section_statement
     ((bfd_vma) 0, "*default*",
Index: emultempl/beos.em
===================================================================
RCS file: /cvs/src/src/ld/emultempl/beos.em,v
retrieving revision 1.11
diff -u -p -r1.11 beos.em
--- beos.em	2001/08/04 01:21:43	1.11
+++ beos.em	2001/08/14 01:53:38
@@ -7,7 +7,8 @@ else
 fi
 cat >e${EMULATION_NAME}.c <<EOF
 /* This file is part of GLD, the Gnu Linker.
-   Copyright 1995, 1996, 1997, 1998, 2000 Free Software Foundation, Inc.
+   Copyright 1995, 1996, 1997, 1998, 2000, 2001
+   Free Software Foundation, Inc.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -813,7 +814,7 @@ gld${EMULATION_NAME}_place_orphan (file,
      The sections still have to be sorted, but that has to wait until
      all such sections have been processed by us.  The sorting is done by
      sort_sections.  */
-  wild_doit (&l->wild_statement.children, s, os, file);
+  lang_add_section (&l->wild_statement.children, s, os, file);
 
   return true;
 }
Index: emultempl/elf32.em
===================================================================
RCS file: /cvs/src/src/ld/emultempl/elf32.em,v
retrieving revision 1.55
diff -u -p -r1.55 elf32.em
--- elf32.em	2001/08/13 14:28:57	1.55
+++ elf32.em	2001/08/14 01:53:40
@@ -1085,7 +1085,7 @@ gld${EMULATION_NAME}_place_orphan (file,
 	{
 	  /* We already have an output section statement with this
 	     name, and its bfd section, if any, has compatible flags.  */
-	  wild_doit (&os->children, s, os, file);
+	  lang_add_section (&os->children, s, os, file);
 	  return true;
 	}
     }
@@ -1100,7 +1100,7 @@ gld${EMULATION_NAME}_place_orphan (file,
       && strncmp (secname, ".gnu.warning.", sizeof ".gnu.warning." - 1) == 0
       && hold_text.os != NULL)
     {
-      wild_doit (&hold_text.os->children, s, hold_text.os, file);
+      lang_add_section (&hold_text.os->children, s, hold_text.os, file);
       return true;
     }
 
@@ -1205,7 +1205,7 @@ gld${EMULATION_NAME}_place_orphan (file,
 					    (etree_type *) NULL,
 					    (etree_type *) NULL);
 
-  wild_doit (&os->children, s, os, file);
+  lang_add_section (&os->children, s, os, file);
 
   lang_leave_output_section_statement
     ((bfd_vma) 0, "*default*",
Index: emultempl/hppaelf.em
===================================================================
RCS file: /cvs/src/src/ld/emultempl/hppaelf.em,v
retrieving revision 1.12
diff -u -p -r1.12 hppaelf.em
--- hppaelf.em	2001/03/13 06:14:27	1.12
+++ hppaelf.em	2001/08/14 01:53:40
@@ -258,7 +258,7 @@ hppaelf_add_stub_section (stub_sec_name,
 
   info.input_section = input_section;
   lang_list_init (&info.add);
-  wild_doit (&info.add, stub_sec, os, stub_file);
+  lang_add_section (&info.add, stub_sec, os, stub_file);
 
   if (info.add.head == NULL)
     goto err_ret;
Index: emultempl/pe.em
===================================================================
RCS file: /cvs/src/src/ld/emultempl/pe.em,v
retrieving revision 1.46
diff -u -p -r1.46 pe.em
--- pe.em	2001/08/02 23:03:10	1.46
+++ pe.em	2001/08/14 01:53:42
@@ -9,7 +9,7 @@ rm -f e${EMULATION_NAME}.c
 (echo;echo;echo;echo;echo)>e${EMULATION_NAME}.c # there, now line numbers match ;-)
 cat >>e${EMULATION_NAME}.c <<EOF
 /* This file is part of GLD, the Gnu Linker.
-   Copyright 1995, 1996, 1997, 1998, 1999, 2000
+   Copyright 1995, 1996, 1997, 1998, 1999, 2000, 2001
    Free Software Foundation, Inc.
 
 This program is free software; you can redistribute it and/or modify
@@ -1458,7 +1458,7 @@ gld_${EMULATION_NAME}_place_orphan (file
       && os->bfd_section != NULL
       && ((s->flags ^ os->bfd_section->flags) & (SEC_LOAD | SEC_ALLOC)) == 0)
     {
-      wild_doit (&add_child, s, os, file);
+      lang_add_section (&add_child, s, os, file);
     }
   else
     {
@@ -1562,7 +1562,7 @@ gld_${EMULATION_NAME}_place_orphan (file
 						(etree_type *) NULL,
 						(etree_type *) NULL);
 
-      wild_doit (&add_child, s, os, file);
+      lang_add_section (&add_child, s, os, file);
 
       lang_leave_output_section_statement
 	((bfd_vma) 0, "*default*",


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Index: ldlang.c
===================================================================
RCS file: /cvs/src/src/ld/ldlang.c,v
retrieving revision 1.56
diff -u -p -r1.56 ldlang.c
--- ldlang.c	2001/08/03 01:11:21	1.56
+++ ldlang.c	2001/08/14 01:53:36
@@ -1012,11 +1012,11 @@ section_already_linked (abfd, sec, data)
 	      break;
 	    }
 
-	  /* Set the output_section field so that wild_doit does not
-	     create a lang_input_section structure for this section.
-	     Since there might be a symbol in the section being
-	     discarded, we must retain a pointer to the section which
-	     we are really going to use.  */
+	  /* Set the output_section field so that lang_add_section
+	     does not create a lang_input_section structure for this
+	     section.  Since there might be a symbol in the section
+	     being discarded, we must retain a pointer to the section
+	     which we are really going to use.  */
 	  sec->output_section = bfd_abs_section_ptr;
 	  sec->kept_section = l->sec;
 
@@ -1098,7 +1098,7 @@ wildcardp (pattern)
    input file which holds SECTION.  */
 
 void
-wild_doit (ptr, section, output, file)
+lang_add_section (ptr, section, output, file)
      lang_statement_list_type *ptr;
      asection *section;
      lang_output_section_statement_type *output;
@@ -1372,18 +1372,18 @@ output_section_callback (ptr, sec, secti
      of the current list.  */
 
   if (before == NULL)
-    wild_doit (&ptr->children, section,
-	       (lang_output_section_statement_type *) output,
-	       file);
+    lang_add_section (&ptr->children, section,
+		      (lang_output_section_statement_type *) output,
+		      file);
   else
     {
       lang_statement_list_type list;
       lang_statement_union_type **pp;
 
       lang_list_init (&list);
-      wild_doit (&list, section,
-		 (lang_output_section_statement_type *) output,
-		 file);
+      lang_add_section (&list, section,
+			(lang_output_section_statement_type *) output,
+			file);
 
       /* If we are discarding the section, LIST.HEAD will
 	 be NULL.  */
@@ -3739,18 +3739,18 @@ lang_place_orphans ()
 			    lang_output_section_statement_lookup (".bss");
 
 			}
-		      wild_doit (&default_common_section->children, s,
-				 default_common_section, file);
+		      lang_add_section (&default_common_section->children, s,
+					default_common_section, file);
 		    }
 		}
 	      else if (ldemul_place_orphan (file, s))
 		;
 	      else
 		{
-		  lang_output_section_statement_type *os =
-		  lang_output_section_statement_lookup (s->name);
+		  lang_output_section_statement_type *os;
 
-		  wild_doit (&os->children, s, os, file);
+		  os = lang_output_section_statement_lookup (s->name);
+		  lang_add_section (&os->children, s, os, file);
 		}
 	    }
 	}